@@ -521,6 +521,7 @@ gnome_rr_config_load_current (GnomeRRConfig *config, GError **error)
 
 	output->priv->name = g_strdup (gnome_rr_output_get_name (rr_output));
 	output->priv->connected = gnome_rr_output_is_connected (rr_output);
+	output->priv->display_name = g_strdup (gnome_rr_output_get_display_name (rr_output));
 
 	if (!output->priv->connected)
 	{
@@ -553,12 +554,6 @@ gnome_rr_config_load_current (GnomeRRConfig *config, GError **error)
 		output->priv->product = 0;
 		output->priv->serial = 0;
 	    }
-
-	    if (gnome_rr_output_is_laptop (rr_output))
-		output->priv->display_name = g_strdup (_("Laptop"));
-	    else
-		output->priv->display_name = make_display_name (info);
-		
 	    g_free (info);
 		
 	    crtc = gnome_rr_output_get_crtc (rr_output);
@@ -1175,14 +1170,14 @@ gboolean
 gnome_rr_config_ensure_primary (GnomeRRConfig *configuration)
 {
         int i;
-        GnomeRROutputInfo  *laptop;
+        GnomeRROutputInfo  *builtin_display;
         GnomeRROutputInfo  *top_left;
         gboolean found;
 	GnomeRRConfigPrivate *priv;
 
 	g_return_val_if_fail (GNOME_IS_RR_CONFIG (configuration), FALSE);
 
-        laptop = NULL;
+        builtin_display = NULL;
         top_left = NULL;
         found = FALSE;
 	priv = configuration->priv;
@@ -1209,17 +1204,17 @@ gnome_rr_config_ensure_primary (GnomeRRConfig *configuration)
                         && info->priv->y < top_left->priv->y)) {
                         top_left = info;
                 }
-                if (laptop == NULL
-                    && _gnome_rr_output_name_is_laptop (info->priv->name)) {
+                if (builtin_display == NULL
+                    && _gnome_rr_output_name_is_builtin_display (info->priv->name)) {
                         /* shame we can't find the connector type
-                           as with gnome_rr_output_is_laptop */
-                        laptop = info;
+                           as with gnome_rr_output_is_builtin_display */
+                        builtin_display = info;
                 }
         }
 
         if (!found) {
-                if (laptop != NULL) {
-                        laptop->priv->primary = TRUE;
+                if (builtin_display != NULL) {
+                        builtin_display->priv->primary = TRUE;
                 } else if (top_left != NULL) {
                         /* Note: top_left can be NULL if all outputs are off */
                         top_left->priv->primary = TRUE;
