@@ -1475,7 +1475,7 @@ read_edid_data (GnomeRROutput *output, gsize *len)
 
     if (result)
     {
-	if (*len % 128 == 0)
+	if (*len > 0 && *len % 128 == 0)
 	    return result;
 	else
 	    g_free (result);
@@ -2248,7 +2248,8 @@ gnome_rr_crtc_set_config_with_time (GnomeRRCrtc      *crtc,
 	for (i = 0; i < n_outputs; ++i)
 	    g_array_append_val (output_ids, outputs[i]->id);
     }
-    
+
+    gdk_error_trap_push ();
     status = XRRSetCrtcConfig (DISPLAY (crtc), info->resources, crtc->id,
 			       timestamp, 
 			       x, y,
@@ -2259,16 +2260,16 @@ gnome_rr_crtc_set_config_with_time (GnomeRRCrtc      *crtc,
     
     g_array_free (output_ids, TRUE);
 
-    if (status == RRSetConfigSuccess)
-	result = TRUE;
-    else {
-	result = FALSE;
+    if (gdk_error_trap_pop () || status != RRSetConfigSuccess) {
 	/* Translators: CRTC is a CRT Controller (this is X terminology).
 	 * It is *very* unlikely that you'll ever get this error, so it is
 	 * only listed for completeness. */
 	g_set_error (error, GNOME_RR_ERROR, GNOME_RR_ERROR_RANDR_ERROR,
 		     _("could not set the configuration for CRTC %d"),
 		     (int) crtc->id);
+        return FALSE;
+    } else {
+        result = TRUE;
     }
     
     return result;
